@@ -1,4 +1,5 @@
 import ctypes
+from typing import List
 from typing import Optional
 from typing import Union
 
@@ -49,7 +50,7 @@ class Clipboard:
         if self.open():
             return self
         else:
-            raise Exception('Unable to open clipboard.')
+            raise Exception("Unable to open clipboard.")
 
     def __exit__(
         self, exception_type, exception_value, exception_traceback
@@ -75,16 +76,16 @@ class Clipboard:
         self.unlock()
         CloseClipboard()
 
-    def available_formats(self) -> list[int]:
+    def available_formats(self) -> List[int]:
         """Return all available clipboard formats on clipboard.
 
         First format is the format on the clipboard, depending on your system.
         """
         # TODO Add this to a base class (HTML clipboard could use this)
 
-        logger.info('Getting available clipboard formats...')
+        logger.info("Getting available clipboard formats...")
 
-        def get_formats(formats: list = None) -> list[int]:
+        def get_formats(formats: List = None) -> List[int]:
 
             if formats is None:
                 formats = [EnumClipboardFormats(0)]
@@ -95,7 +96,7 @@ class Clipboard:
             else:
                 return formats + [EnumClipboardFormats(last_format)]
 
-        available_formats: list[int] = []
+        available_formats: List[int] = []
         if not self.opened:
             with self:
                 available_formats = self.available_formats()
@@ -106,6 +107,14 @@ class Clipboard:
 
     def __getitem__(self, format: Union[int, ClipboardFormat] = None):
 
+        return self.get_clipboard(format)
+
+    def get_clipboard(self, format: Union[int, ClipboardFormat] = None):
+
+        if not self.opened:
+            with self:
+                return self.get_clipboard(format=format)
+
         if format is None:
             format = self.format
         else:
@@ -114,8 +123,8 @@ class Clipboard:
         if format not in self.available_formats():
             formats = self.available_formats()
             message = (
-                f'{format} not supported. Choose from following...\n'
-                + '\n'.join(map(str, formats))
+                f"{format} not supported. Choose from following...\n"
+                + "\n".join(map(str, formats))
             )
             raise Exception(message)
 
@@ -125,7 +134,7 @@ class Clipboard:
         self.size = GlobalSize(self.address)
 
         if not self.size:
-            raise Exception('Get Clipboard failed...')
+            raise Exception("Get Clipboard failed...")
 
         if format == ClipboardFormat.CF_UNICODETEXT.value:
 
@@ -156,11 +165,14 @@ class Clipboard:
 
         format = self.resolve_format(format)
         self.empty()
-
         self.set_clipboard(content, format)
 
     def set_clipboard(self, content: str, format=None) -> HANDLE:
 
+        if not self.opened:
+            with self:
+                return self.set_clipboard(content=content, format=format)
+
         if format is None:
             format = self.format
         format = self.resolve_format(format)
@@ -175,7 +187,7 @@ class Clipboard:
             GMEM_ZEROINIT = 0x0040
 
             # Needs a special encoding...
-            content_bytes: bytes = content.encode(encoding='utf-16le')
+            content_bytes: bytes = content.encode(encoding="utf-16le")
 
             alloc_handle = GlobalAlloc(
                 GMEM_MOVEABLE | GMEM_ZEROINIT, len(content_bytes) + 2
@@ -195,7 +207,7 @@ class Clipboard:
             GMEM_ZEROINIT = 0x0040
 
             # Needs a special encoding...
-            html_content_bytes: bytes = content.encode(encoding='utf-16le')
+            html_content_bytes: bytes = content.encode(encoding="utf-16le")
 
             alloc_handle = GlobalAlloc(
                 GMEM_MOVEABLE | GMEM_ZEROINIT, len(content) + 2
@@ -207,12 +219,12 @@ class Clipboard:
             set_handle = SetClipboardData(format, alloc_handle)
         else:
             raise Exception(
-                f'{format} not supported for setting to clipboard.'
+                f"{format} not supported for setting to clipboard."
             )
 
         if set_handle is False:
             # handle will be set to NULL
-            raise Exception('Set Clipboard failed...')
+            raise Exception("Set Clipboard failed...")
 
         return set_handle
 
@@ -229,18 +241,22 @@ class Clipboard:
         return GlobalUnlock(handle)
 
     def resolve_format(self, format: Union[ClipboardFormat, str, int]) -> int:
+        """Given an integer, respresenting a clipboard format, or a
+        ClipboardFormat object, return the respective integer."""
 
         if isinstance(format, ClipboardFormat):
             format = format.value
-        elif isinstance(format, str):
-            format = ClipboardFormat[format].value
         elif isinstance(format, int):
             pass
-        else:
-            raise Exception(
-                f'{format} is not a valid format. Choose from following...\n'
-                + '\n'.join(map(str, ClipboardFormat))
-            )
+        elif isinstance(format, str):
+            try:
+                format = ClipboardFormat[format].value
+            except KeyError:
+                # Not a Supported Format
+                raise ValueError(
+                    f"{format} is not a valid format. Choose from following...\n"
+                    + "\n".join(map(str, ClipboardFormat))
+                )
 
         return format  # type: ignore
 
